==> planeshift-0.3.016.tar.bz2: planeshift-0.3.016/src/server/database/mysql/sc_npc_definitions.sql <==
# MySQL-Front Dump 1.16 beta
#
# Host: localhost Database: planeshift
#--------------------------------------------------------
# Server version 4.0.18-max-nt
#
# Table structure for table 'sc_npc_definitions'
#

CREATE TABLE sc_npc_definitions (
  char_id int(10) NOT NULL DEFAULT '0' ,
  name varchar(30) ,
  npctype varchar(30) ,
  region varchar(30) ,
  move_vel_override float(10,2) DEFAULT '0.00' ,
  ang_vel_override float(10,2) DEFAULT '0.00' ,
  char_id_owner int(10) unsigned DEFAULT '0' ,
  console_debug char(1) DEFAULT '0' ,
  PRIMARY KEY (char_id)
);


#
# Dumping data for table 'sc_npc_definitions'
#

INSERT INTO sc_npc_definitions VALUES("4","MaleEnki","Wanderer","wander region","0.00","0.00","0","N");
INSERT INTO sc_npc_definitions VALUES("5","Smith","smith","","0.00","0.00","0","N");
INSERT INTO sc_npc_definitions VALUES("6","Fighter1","Fighter","","0.00","0.00","0","N");
INSERT INTO sc_npc_definitions VALUES("7","Fighter2","On Sight Fighter","","0.00","0.00","0","N");
INSERT INTO sc_npc_definitions VALUES("8","Merchant","Wanderer","wander region","0.00","0.00","0","N");
INSERT INTO sc_npc_definitions VALUES("10","FAMILIAR:Rogue","Minion","wander region","0.00","0.00","0","N");
INSERT INTO sc_npc_definitions VALUES("20","Tribe1Member1","Tribe","","0.00","0.00","0","N");
INSERT INTO sc_npc_definitions VALUES("21","Tribe1Member2","Tribe","","0.00","0.00","0","N");
INSERT INTO sc_npc_definitions VALUES("22","Tribe1Member3","Tribe","","0.00","0.00","0","N");
INSERT INTO sc_npc_definitions VALUES("23","Tribe1Member4","Tribe","","0.00","0.00","0","N");

==> planeshift-0.3.017.tar.bz2: planeshift-0.3.017/src/server/database/mysql/sc_npc_definitions.sql <==
# MySQL-Front Dump 1.16 beta
#
# Host: localhost Database: planeshift
#--------------------------------------------------------
# Server version 4.0.18-max-nt
#
# Table structure for table 'sc_npc_definitions'
#

CREATE TABLE sc_npc_definitions (
  char_id int(10) NOT NULL DEFAULT '0' ,
  name varchar(30) ,
  npctype varchar(30) ,
  region varchar(30) ,
  move_vel_override float(10,2) DEFAULT '0.00' ,
  ang_vel_override float(10,2) DEFAULT '0.00' ,
  char_id_owner int(10) unsigned DEFAULT '0' ,
  console_debug char(1) DEFAULT '0' ,
  PRIMARY KEY (char_id)
);


#
# Dumping data for table 'sc_npc_definitions'
#

INSERT INTO sc_npc_definitions VALUES("4","MaleEnki","Wanderer","wander region","0.00","0.00","0","N");
INSERT INTO sc_npc_definitions VALUES("5","Smith","smith","","0.00","0.00","0","N");
INSERT INTO sc_npc_definitions VALUES("6","Fighter1","Fighter","","0.00","0.00","0","N");
INSERT INTO sc_npc_definitions VALUES("7","Fighter2","On Sight Fighter","","0.00","0.00","0","N");
INSERT INTO sc_npc_definitions VALUES("8","Merchant","Wanderer","wander region","0.00","0.00","0","N");
INSERT INTO sc_npc_definitions VALUES("10","FAMILIAR:Rogue","Minion","wander region","0.00","0.00","0","N");
INSERT INTO sc_npc_definitions VALUES("14","DictMaster1","Answerer","","0.00","0.00","0","N");
INSERT INTO sc_npc_definitions VALUES("15","DictMaster2","Answerer","","0.00","0.00","0","N");
INSERT INTO sc_npc_definitions VALUES("20","TribeMember","Tribe","","0.00","0.00","0","N");
INSERT INTO sc_npc_definitions VALUES("21","MoveMaster1","MoveTest1","","0.00","0.00","0","N");
INSERT INTO sc_npc_definitions VALUES("22","MoveMaster2","MoveTest2","","0.00","0.00","0","N");
INSERT INTO sc_npc_definitions VALUES("23","MoveMaster3","MoveTest3","","0.00","0.00","0","N");
INSERT INTO sc_npc_definitions VALUES("24","MoveMaster4","MoveTest4","","0.00","0.00","0","N");
